@@ -5,13 +5,14 @@ import os
 
 os.environ['TOKENIZERS_PARALLELISM'] = 'false'
 
-
 st.set_page_config(
     page_title="Text Generation Using Keywords",
 )
 
 
-@st.cache(suppress_st_warning=True, ttl=1000)
+@st.cache(suppress_st_warning=True,
+          ttl=1000,
+          show_spinner=False)
 def generate(keywords, model="k2t"):
     nlp = pipeline(model)
     return nlp(keywords)
@@ -41,8 +42,9 @@ def display():
                        key='1')
 
     if st.button("Generate text"):
-        text = generate(keywords=keywords,
-                        model=model)
+        with st.spinner("Connecting the Dots..."):
+            text = generate(keywords=keywords,
+                            model=model)
         st.write("# Generated Sentence:")
         st.write("## {}".format(text))
 
