@@ -4,8 +4,6 @@ Keytotext converts a list of Keywords to sentences and larger texts
 """
 
 
-__version__ = "0.1.6"
+__version__ = "0.1.7"
 
 from .pipeline import pipeline
-from .eval import eval
-from .trainer import trainer
